image_pin_point library

Classes

ImagePinPoint
A utility class that provides functionality for capturing, processing, and saving images with pins
ImagePinPointContainer
A widget that displays an image and allows adding pins/markers at specific points
ImagePinPointController
A mixin class that provides methods for image manipulation and pin point functionality
ImagePinPointOptions
A widget that displays a collection of pin style options for the ImagePinPoint system.
OperationResult
Represents the status of an operation result.
Pinner
A customizable pin that can contain any widget as its visual representation
PinPositioner
A widget that centers its child at the origin point