ImagePinPoint class

A utility class that provides functionality for capturing, processing, and saving images with pins

This class contains static methods for:

  • Capturing the current state of an ImagePinPoint widget
  • Handling image orientation issues
  • Saving images to the device gallery

Constructors

ImagePinPoint()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

saveImage(GlobalKey<State<StatefulWidget>> imagePinPointKey, {bool skipSaveToGallery = true, String? customName}) Future<OperationResult>
Captures and saves the current image state including pins