imagePinPointKey property

GlobalKey<State<StatefulWidget>> imagePinPointKey
final

Key used for capturing the widget state as an image This is required for the image saving functionality

Implementation

final GlobalKey imagePinPointKey;