ImagePinPointController class mixin

A mixin class that provides methods for image manipulation and pin point functionality

This mixin can be used by any widget that needs to handle image operations such as:

  • Loading images and determining their dimensions
  • Converting tap coordinates to image coordinates
  • Capturing and saving images with pins to the device gallery
  • Handling image orientation issues that may occur on different devices

Constructors

ImagePinPointController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTapDown(TapDownDetails details, GlobalKey<State<StatefulWidget>> imageKey, dynamic callBack(Offset), double imageWidth, double imageHeight) → void
Processes tap events and converts tap coordinates to image coordinates
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited