Pinner class

A customizable pin that can contain any widget as its visual representation

This class allows for flexible pin designs by:

  • Storing the exact position where the pin should be placed
  • Containing any Flutter widget to be rendered at that position
  • Supporting the pin positioning system used in ImagePinPointContainer

Constructors

Pinner({required Offset position, required Widget widget})
Creates a new custom pin with the specified position and widget
const

Properties

hashCode int
The hash code for this object.
no setterinherited
position Offset
The position of the pin on the image (in image coordinates)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget
The widget to be displayed at the pin position
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited