onPinsEditingComplete property
Callback triggered when the user finishes adding pins to the image
This is similar to onEditingComplete in TextField - it's called when the user has finished interacting with the pins and no new pins are being added. This is useful for performing actions only after the user has completed their pin placement, rather than during each pin update.
Implementation
final void Function(List<Pinner> pins)? onPinsEditingComplete;