OperationResult class
Represents the status of an operation result.
This class encapsulates information about whether an operation succeeded, a descriptive message about the result, and an optional file path if the operation involved a file.
Constructors
- OperationResult({required bool isSuccess, required String message, String? filePath})
- Creates a new OperationResult instance.
Properties
- filePath → String?
-
Optional path to a file related to the operation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Indicates if the operation was successful.
final
- message → String
-
A descriptive message about the operation result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited